@@ -1,37 +1,15 @@
-from django.contrib.sites.managers import CurrentSiteManager as BaseCurrentSiteManager
+from __future__ import annotations
+
 from django.contrib.sites.models import Site
 from django.db import models
 
+from .model_mixins import CurrentSiteManager, SiteModelMixin  # noqa
+
 
 class SiteModelError(Exception):
     pass
 
 
-class CurrentSiteManager(BaseCurrentSiteManager):
-
-    use_in_migrations = True
-
-    def get_by_natural_key(self, subject_identifier):
-        return self.get(subject_identifier=subject_identifier)
-
-
-class SiteModelMixin(models.Model):
-
-    site = models.ForeignKey(
-        Site, on_delete=models.PROTECT, null=True, editable=False, related_name="+"
-    )
-
-    on_site = CurrentSiteManager()
-
-    def save(self, *args, **kwargs):
-        if not self.site:
-            self.site = Site.objects.get_current()
-        super().save(*args, **kwargs)
-
-    class Meta:
-        abstract = True
-
-
 class SiteProfile(models.Model):
 
     id = models.BigAutoField(primary_key=True)
@@ -40,6 +18,8 @@ class SiteProfile(models.Model):
 
     country_code = models.CharField(max_length=15, null=True)
 
+    languages = models.TextField(null=True)
+
     title = models.CharField(max_length=250, null=True)
 
     description = models.TextField(null=True)
@@ -67,5 +47,9 @@ class EdcSite(Site):
     def country_code(self) -> str:
         return SiteProfile.objects.get(site=self).country_code
 
+    @property
+    def languages(self) -> str | None:
+        return SiteProfile.objects.get(site=self).languages
+
     class Meta:
         proxy = True
