@@ -1,7 +1,7 @@
 from edc_sites.single_site import SingleSite
 
 fqdn = "clinicedc.org"
-
+languages = {"en": "English"}
 sites: list[SingleSite] = [
     SingleSite(
         10,
@@ -9,6 +9,7 @@ sites: list[SingleSite] = [
         title="Mochudi",
         country="botswana",
         country_code="bw",
+        languages=languages,
         domain=f"mochudi.bw.{fqdn}",
     ),
     SingleSite(
@@ -17,6 +18,7 @@ sites: list[SingleSite] = [
         title="Molepolole",
         country="botswana",
         country_code="bw",
+        languages=languages,
         fqdn=fqdn,
     ),
     SingleSite(
@@ -25,6 +27,7 @@ sites: list[SingleSite] = [
         title="Lobatse",
         country="botswana",
         country_code="bw",
+        languages=languages,
         fqdn=fqdn,
     ),
     SingleSite(
@@ -33,6 +36,7 @@ sites: list[SingleSite] = [
         title="Gaborone",
         country="botswana",
         country_code="bw",
+        languages=languages,
         fqdn=fqdn,
     ),
     SingleSite(
@@ -41,6 +45,7 @@ sites: list[SingleSite] = [
         title="Karakobis",
         country="botswana",
         country_code="bw",
+        languages=languages,
         fqdn=fqdn,
     ),
     SingleSite(
@@ -49,6 +54,7 @@ sites: list[SingleSite] = [
         title="Windhoek",
         country="namibia",
         country_code="na",
+        languages=languages,
         fqdn=fqdn,
     ),
 ]
@@ -61,6 +67,7 @@ more_sites = [
         title="Windhoek",
         country="namibia",
         country_code="na",
+        languages=languages,
         fqdn=fqdn,
     ),
 ]
